import matplotlib.pyplot as plt
import matplotlib
import pandas as pd


def autolabel(ax, rects):
    """Attach a text label above each bar in *rects*, displaying its height."""
    for rect in rects:
        height = rect.get_height()
        ax.annotate('{}'.format(height),
                    xy=(rect.get_x() + rect.get_width() / 2, height),
                    xytext=(0, 3),  # 3 points vertical offset
                    textcoords="offset points",
                    ha='center', va='bottom')



df1 = pd.read_csv("locality.csv")

df1.plot.bar()
plt.legend(labels=["SSD 1K Random", "SSD 1K Sequential", "Memory 8 Bytes Random", "Memory 8 Bytes Sequential"])

ax1 = plt.axes()
ax1.get_xaxis().set_ticks([])

rects = ax1.patches
autolabel(ax1, rects)

SMALL_SIZE = 12
MEDIUM_SIZE = 14
BIGGER_SIZE = 18


plt.rc('font', size=SMALL_SIZE)          # controls default text sizes
plt.rc('axes', titlesize=SMALL_SIZE)     # fontsize of the axes title
plt.rc('axes', labelsize=MEDIUM_SIZE)    # fontsize of the x and y labels
plt.rc('xtick', labelsize=SMALL_SIZE)    # fontsize of the tick labels
plt.rc('ytick', labelsize=SMALL_SIZE)    # fontsize of the tick labels
plt.rc('legend', fontsize=SMALL_SIZE)    # legend fontsize
plt.rc('figure', titlesize=BIGGER_SIZE)  # fontsize of the figure title

plt.xlabel("Access Method")
plt.ylabel("Bandwidth (MB/sec)")
plt.title("Disk and Memory Bandwidth for Different Access Patterns")
plt.show()  