#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <time.h>

#define NITERS 1000000
#define BLOCKSIZE 1024

//create the file, and write data to it -- if we don't
//write, the os will not allocate the bytes on disk
void create_file(char *fname, long len) {
    FILE *fp = fopen("myfile", "w");
    char data[1000000];
    for (int i = 0; i < 1000000; i++)
    {
        data[i] = rand ();
    }


    while (len > 0) {
        fwrite (data, 1000000, 1, fp);
        len -= 1000000;
    }
    fclose(fp);
}

int main() {
    long len = 1024 * 1024 * 2000;
    char c[1024];
    long idx = 0;
    FILE *fp;

    //test random reading
    create_file("myfile", len);
    fp = fopen("myfile", "r");

    clock_t start, end;
    system("sync && purge"); //macos way to flush 
    start = clock();

    for (int i = 0; i < NITERS; i++) {
        fseek(fp, idx, SEEK_SET);
        fread(c, BLOCKSIZE, 1, fp);        
        idx = (idx + 446157) % len;
    }

    end = clock();
    double time = ((double) (end - start)) / CLOCKS_PER_SEC;
    printf ("time for 1M random accesses = %.3f\n", time);
    printf ("bandwidth = %.2f MB/sec, iops = %.2f\n", 
        (NITERS * BLOCKSIZE) / (time * 1024 * 1024), 
        NITERS/time);

    fclose(fp);
    remove("myfile");

    //test sequential reading
    create_file("myfile", len);
    fp = fopen("myfile", "r");
    system("sync && purge");

    start = clock();

    for (int i = 0; i < NITERS; i++) {
        fread(c, BLOCKSIZE, 1, fp);        
    }

    end = clock();
    time = ((double) (end - start)) / CLOCKS_PER_SEC;
    fclose(fp);
    remove("myfile");


    printf ("time for 1M sequential accesses = %.3f\n",  time);
    printf ("bandwidth = %.2f MB/sec, iops = %.2f\n", 
        (NITERS * BLOCKSIZE) / (time * 1024 * 1024), 
        NITERS/time);
}